@@ -284,9 +284,12 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
 
     KCalCore::Attachment::Ptr att = attitem->attachment();
     if (att->isUri()) {
-        Q_EMIT openURL(QUrl(att->uri()));
+        openURL(QUrl(att->uri()));
     } else {
-        KRun::runUrl(mAttachmentView->tempFileForAttachment(att), att->mimeType(), nullptr, true);
+        KRun::RunFlags flags;
+        flags |= KRun::DeleteTemporaryFiles;
+        flags |= KRun::RunExecutables;
+        KRun::runUrl(mAttachmentView->tempFileForAttachment(att), att->mimeType(), nullptr, flags);
     }
 }
 
@@ -419,7 +422,7 @@ void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
         probablyWeHaveUris = true;
     }
     QMenu menu;
-    QAction *linkAction = nullptr, *cancelAction;
+    QAction *linkAction = nullptr, *cancelAction = nullptr;
     if (probablyWeHaveUris) {
         linkAction
             = menu.addAction(QIcon::fromTheme(QStringLiteral("insert-link")),
@@ -494,13 +497,13 @@ void IncidenceAttachment::setupActions()
     KActionCollection *ac = new KActionCollection(this);
 //  ac->addAssociatedWidget( this );
 
-    mOpenAction = new QAction(i18nc("@action:inmenu open the attachment in a viewer",
+    mOpenAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open")),i18nc("@action:inmenu open the attachment in a viewer",
                                     "&Open"), this);
     connect(mOpenAction, &QAction::triggered, this, &IncidenceAttachment::showSelectedAttachments);
     ac->addAction(QStringLiteral("view"), mOpenAction);
     mPopupMenu->addAction(mOpenAction);
 
-    mSaveAsAction = new QAction(i18nc("@action:inmenu save the attachment to a file",
+    mSaveAsAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18nc("@action:inmenu save the attachment to a file",
                                       "Save As..."), this);
     connect(mSaveAsAction, &QAction::triggered, this,
             &IncidenceAttachment::saveSelectedAttachments);
@@ -519,7 +522,7 @@ void IncidenceAttachment::setupActions()
     mPopupMenu->addSeparator();
 #endif
 
-    mDeleteAction = new QAction(i18nc("@action:inmenu remove the attachment",
+    mDeleteAction = new QAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action:inmenu remove the attachment",
                                       "&Remove"), this);
     connect(mDeleteAction, &QAction::triggered, this,
             &IncidenceAttachment::removeSelectedAttachments);
@@ -528,7 +531,7 @@ void IncidenceAttachment::setupActions()
     mPopupMenu->addAction(mDeleteAction);
     mPopupMenu->addSeparator();
 
-    mEditAction = new QAction(i18nc("@action:inmenu show a dialog used to edit the attachment",
+    mEditAction = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18nc("@action:inmenu show a dialog used to edit the attachment",
                                     "&Properties..."), this);
     connect(mEditAction, &QAction::triggered, this, &IncidenceAttachment::editSelectedAttachments);
     ac->addAction(QStringLiteral("edit"), mEditAction);
